@@ -16,15 +16,15 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Optional, Sequence, Tuple, Type, Union
-import pkg_resources
+from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
 
-from google.api_core.client_options import ClientOptions
 from google.api_core import exceptions as core_exceptions
 from google.api_core import gapic_v1
 from google.api_core import retry as retries
+from google.api_core.client_options import ClientOptions
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
+import pkg_resources
 
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
@@ -33,9 +33,10 @@ except AttributeError:  # pragma: NO COVER
 
 from google.cloud.orchestration.airflow.service_v1.services.image_versions import pagers
 from google.cloud.orchestration.airflow.service_v1.types import image_versions
-from .transports.base import ImageVersionsTransport, DEFAULT_CLIENT_INFO
-from .transports.grpc_asyncio import ImageVersionsGrpcAsyncIOTransport
+
 from .client import ImageVersionsClient
+from .transports.base import DEFAULT_CLIENT_INFO, ImageVersionsTransport
+from .transports.grpc_asyncio import ImageVersionsGrpcAsyncIOTransport
 
 
 class ImageVersionsAsyncClient:
@@ -213,11 +214,18 @@ class ImageVersionsAsyncClient:
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud.orchestration.airflow import service_v1
 
-            def sample_list_image_versions():
+            async def sample_list_image_versions():
                 # Create a client
-                client = service_v1.ImageVersionsClient()
+                client = service_v1.ImageVersionsAsyncClient()
 
                 # Initialize request argument(s)
                 request = service_v1.ListImageVersionsRequest(
@@ -227,7 +235,7 @@ class ImageVersionsAsyncClient:
                 page_result = client.list_image_versions(request=request)
 
                 # Handle the response
-                for response in page_result:
+                async for response in page_result:
                     print(response)
 
         Args:
@@ -289,12 +297,20 @@ class ImageVersionsAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__aiter__` convenience method.
         response = pagers.ListImageVersionsAsyncPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
